@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2022 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ void ABconfig::reset (void)
     _matrix [3][1] = -0.866f; 
     _matrix [3][2] = -0.866f; 
     _matrix [3][3] =  0.866f; 
-    *_convfile = 0;
+    _convfile [0] = 0;
     for (i = 0; i < 4; i++)
     {
 	_hffilt [i][0] = 8e3f;  // Frequency
@@ -155,7 +155,8 @@ int ABconfig::save (const char *file)
 int ABconfig::load (const char *file)
 {
     int           i, j, n, err, form;
-    const char    *p, *q;
+    const char    *p, *q;	
+    char          *r;
     FILE          *F;
     char          s [1024];
     Oscform       Z (4096);
@@ -168,8 +169,8 @@ int ABconfig::load (const char *file)
 	fprintf (stderr, "Can't open file '%s' for reading\n", s);
         return 1;
     } 
-
     reset (); // Set defaults for any missing data.
+
     if (Z.read (F) || ((p = Z.get_command ()) == 0) || strcmp (p, "/tetraproc"))
     {
 	fprintf (stderr, "File '%s' is not a valid configuration file.\n", s);
@@ -222,7 +223,14 @@ int ABconfig::load (const char *file)
 	else if (!strcmp (p, "/convol/file"))
 	{
 	    err = Z.get_string (&q, &n);
-	    if (!err) strcpy (_convfile, q);
+	    if (!err && *q)
+	    {
+                strcpy (_convfile, file);    
+                r = strrchr (_convfile, '/');
+                if (r) r [1] = 0;
+                else strcpy (_convfile, "./");
+    		strcat (_convfile, q);
+	    }
 	}
 	else if (!strcmp (p, "/pmfilt/par"))
 	{
@@ -251,45 +259,3 @@ int ABconfig::load (const char *file)
 }
 
 
-int ABconfig::openconvfile (void)
-{
-    char         *p;
-    struct stat  S;
-
-    if ( stat (_convfile, &S) || ! S_ISREG (S.st_mode)) return 1;
-    p = strrchr (_convfile, '.');
-    if (! p) return 1;
-    if (! strcmp (p, ".ald"))
-    {
-	if (_convdata.open_read (_convfile)) return 1;
-        if ((_convdata.n_chan () != 4) || (_convdata.n_sect () != 4) || (_convdata.n_fram () > 0x1000))
-	{
-	    _convdata.close ();
-	    return 1;
-	}
-	_convdata.alloc ();
-	return 0;
-    }
-    if (! strcmp (p, ".wav"))
-    {
-	if (_convdata.sf_open_read (_convfile)) return 1;
-        if ((_convdata.n_chan () != 4) || (_convdata.n_fram () > 0x4000))
-	{
-	    _convdata.close ();
-	    return 1;
-	}
-	_convdata.set_n_sect (4);
-        _convdata.set_n_fram (_convdata.n_fram () / 4);
-	_convdata.alloc ();
-	return 0;
-    }
-    return 1;
-}
- 
-
-int ABconfig::closeconvfile (void)
-{
-    _convdata.close ();
-    _convdata.deall ();
-    return 0;
-}
