@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2022 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,10 +22,6 @@
 #define __ABCONFIG_H
 
 
-#include "bformat.h"
-#include "impdata.h"
-
-
 class ABconfig
 {
 public:
@@ -35,10 +31,8 @@ public:
     void reset (void);
     int save (const char *name);
     int load (const char *name);
-    int openconvfile (void);
-    int closeconvfile (void);
-
-    enum { EN_LFEQ = 1, EN_MATR = 2, EN_CONV = 4, EN_PMEQ = 8, EN_FORM = 16, EN_ALL = 31 };
+    
+    enum { EN_LFEQ = 1, EN_MATR = 2, EN_CONV = 4, EN_PMEQ = 8, EN_ALL = 15 };
 
     char            _copyright [64];
     char            _descript [64];
@@ -50,7 +44,6 @@ public:
     float           _hffilt [4][9];
     float           _eqgain [4];
     char            _convfile [1024];
-    Impdata         _convdata;
 };
 
 
