@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2025 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -19,9 +19,8 @@
 
 
 #include <string.h>
-#include <sndfile.h>
 #include <math.h>
-#include "bformat.h"
+#include "audiofile.h"
 #include "abprocess.h"
 
 
@@ -29,7 +28,7 @@ ABprocess::ABprocess (void) :
     _mute (0),
     _invb (0),
     _endf (0),
-    _norm (Bformat::FM_FUMA),
+    _norm (NORM_SN3D),
     _enable (0),
     _cerror (0),
     _convol (0)
@@ -57,7 +56,7 @@ void ABprocess::reset (void)
 }
 
 
-void ABprocess::process (unsigned int n, float *p [4], float *q [4])
+void ABprocess::process (unsigned int n, float *inp [4], float *out [4])
 {
     unsigned int  i, j, k;
     float         c0, c1, c2, c3;
@@ -66,33 +65,33 @@ void ABprocess::process (unsigned int n, float *p [4], float *q [4])
 
     // High pass filter.
     _hpconf.process ();
-    _hpfilt [0].process (&_hpconf, n, p [0], q [0]);
-    _hpfilt [1].process (&_hpconf, n, p [1], q [1]);
-    _hpfilt [2].process (&_hpconf, n, p [2], q [2]);
-    _hpfilt [3].process (&_hpconf, n, p [3], q [3]);
+    _hpfilt [0].process (&_hpconf, n, inp [0], out [0]);
+    _hpfilt [1].process (&_hpconf, n, inp [1], out [1]);
+    _hpfilt [2].process (&_hpconf, n, inp [2], out [2]);
+    _hpfilt [3].process (&_hpconf, n, inp [3], out [3]);
 
     // Mute buttons.
-    if (_mute & 1) memset (q [0], 0, n * sizeof (float));
-    if (_mute & 2) memset (q [1], 0, n * sizeof (float));
-    if (_mute & 4) memset (q [2], 0, n * sizeof (float));
-    if (_mute & 8) memset (q [3], 0, n * sizeof (float));
+    if (_mute & 1) memset (out [0], 0, n * sizeof (float));
+    if (_mute & 2) memset (out [1], 0, n * sizeof (float));
+    if (_mute & 4) memset (out [2], 0, n * sizeof (float));
+    if (_mute & 8) memset (out [3], 0, n * sizeof (float));
 
     // LF equaliser.
     if (_enable & ABconfig::EN_LFEQ)
     {
 	if (_enable & ABconfig::EN_CONV)
 	{
-	    _lffilt [0].process (n, q [0], _convol->wr_ptr (0));
-	    _lffilt [1].process (n, q [1], _convol->wr_ptr (1));
-	    _lffilt [2].process (n, q [2], _convol->wr_ptr (2));
-	    _lffilt [3].process (n, q [3], _convol->wr_ptr (3));
+	    _lffilt [0].process (n, out [0], _convol->wr_ptr (0));
+	    _lffilt [1].process (n, out [1], _convol->wr_ptr (1));
+	    _lffilt [2].process (n, out [2], _convol->wr_ptr (2));
+	    _lffilt [3].process (n, out [3], _convol->wr_ptr (3));
 	}
 	else
 	{
-	    _lffilt [0].process (n, q [0], q [0]);
-	    _lffilt [1].process (n, q [1], q [1]);
-	    _lffilt [2].process (n, q [2], q [2]);
-	    _lffilt [3].process (n, q [3], q [3]);
+	    _lffilt [0].process (n, out [0], out [0]);
+	    _lffilt [1].process (n, out [1], out [1]);
+	    _lffilt [2].process (n, out [2], out [2]);
+	    _lffilt [3].process (n, out [3], out [3]);
 	}
     }
 
@@ -101,27 +100,27 @@ void ABprocess::process (unsigned int n, float *p [4], float *q [4])
     {
 	if (!(_enable & ABconfig::EN_LFEQ))
 	{
-	    memcpy (_convol->wr_ptr (0), q [0], n * sizeof (float));
-	    memcpy (_convol->wr_ptr (1), q [1], n * sizeof (float));
-	    memcpy (_convol->wr_ptr (2), q [2], n * sizeof (float));
-	    memcpy (_convol->wr_ptr (3), q [3], n * sizeof (float));
+	    memcpy (_convol->wr_ptr (0), out [0], n * sizeof (float));
+	    memcpy (_convol->wr_ptr (1), out [1], n * sizeof (float));
+	    memcpy (_convol->wr_ptr (2), out [2], n * sizeof (float));
+	    memcpy (_convol->wr_ptr (3), out [3], n * sizeof (float));
 	}
 	_convol->process ();
 	if (!(_enable & ABconfig::EN_PMEQ))
 	{
-	    memcpy (q [0], _convol->rd_ptr (0), n * sizeof (float));
-	    memcpy (q [1], _convol->rd_ptr (1), n * sizeof (float));
-	    memcpy (q [2], _convol->rd_ptr (2), n * sizeof (float));
-	    memcpy (q [3], _convol->rd_ptr (3), n * sizeof (float));
+	    memcpy (out [0], _convol->rd_ptr (0), n * sizeof (float));
+	    memcpy (out [1], _convol->rd_ptr (1), n * sizeof (float));
+	    memcpy (out [2], _convol->rd_ptr (2), n * sizeof (float));
+	    memcpy (out [3], _convol->rd_ptr (3), n * sizeof (float));
 	}
     }
     // Or scalar matrix.
     else if (_enable & ABconfig::EN_MATR)
     {
- 	p0 = q [0];
- 	p1 = q [1];
- 	p2 = q [2];
- 	p3 = q [3];
+ 	p0 = out [0];
+ 	p1 = out [1];
+ 	p2 = out [2];
+ 	p3 = out [3];
 	for (i = 0; i < n; i += 64)
 	{
 	    k = n - i;
@@ -162,17 +161,17 @@ void ABprocess::process (unsigned int n, float *p [4], float *q [4])
     {
 	if (_enable & ABconfig::EN_CONV)
 	{
-  	    _hffilt [0].process (n, _convol->rd_ptr (0), q [0]);
-	    _hffilt [1].process (n, _convol->rd_ptr (1), q [1]);
-	    _hffilt [2].process (n, _convol->rd_ptr (2), q [2]);
-	    _hffilt [3].process (n, _convol->rd_ptr (3), q [3]);
+  	    _hffilt [0].process (n, _convol->rd_ptr (0), out [0]);
+	    _hffilt [1].process (n, _convol->rd_ptr (1), out [1]);
+	    _hffilt [2].process (n, _convol->rd_ptr (2), out [2]);
+	    _hffilt [3].process (n, _convol->rd_ptr (3), out [3]);
 	}
         else
 	{
-  	    _hffilt [0].process (n, q [0], q [0]);
-	    _hffilt [1].process (n, q [1], q [1]);
-	    _hffilt [2].process (n, q [2], q [2]);
-	    _hffilt [3].process (n, q [3], q [3]);
+  	    _hffilt [0].process (n, out [0], out [0]);
+	    _hffilt [1].process (n, out [1], out [1]);
+	    _hffilt [2].process (n, out [2], out [2]);
+	    _hffilt [3].process (n, out [3], out [3]);
 	}
     }
 
@@ -181,9 +180,9 @@ void ABprocess::process (unsigned int n, float *p [4], float *q [4])
     {
         for (i = 0; i < n; i++)
 	{
-	    t = q [1][i];
-	    q [1][i] = q [3][i];
-	    q [3][i] = -t;
+	    t = out [1][i];
+	    out [1][i] = out [3][i];
+	    out [3][i] = -t;
 	}
     }
 
@@ -192,20 +191,20 @@ void ABprocess::process (unsigned int n, float *p [4], float *q [4])
     c1 = (_invb & 2) ? -1 : 1;
     c2 = (_invb & 4) ? -1 : 1;
     c3 = (_invb & 8) ? -1 : 1;
-    if (_norm == Bformat::FM_FUMA)
+    if (_norm == NORM_FUMA)
     {
         c0 *= 0.7071f;
     }
-    else if (_norm == Bformat::FM_N3D)
+    else if (_norm == NORM_N3D)
     {
 	c1 *= 1.7320f;
 	c2 *= 1.7320f;
 	c3 *= 1.7320f;
     }
-    if (c0 != 1.0f) for (i = 0; i < n; i++) q [0][i] *= c0;
-    if (c1 != 1.0f) for (i = 0; i < n; i++) q [1][i] *= c1;
-    if (c2 != 1.0f) for (i = 0; i < n; i++) q [2][i] *= c2;
-    if (c3 != 1.0f) for (i = 0; i < n; i++) q [3][i] *= c3;
+    if (c0 != 1.0f) for (i = 0; i < n; i++) out [0][i] *= c0;
+    if (c1 != 1.0f) for (i = 0; i < n; i++) out [1][i] *= c1;
+    if (c2 != 1.0f) for (i = 0; i < n; i++) out [2][i] *= c2;
+    if (c3 != 1.0f) for (i = 0; i < n; i++) out [3][i] *= c3;
 }
 
 
@@ -257,8 +256,10 @@ int ABprocess::set_matrix (ABconfig *C)
 
 int ABprocess::set_convol (ABconfig *C)
 {
-    int       i, j, k;
-    Convdata  *D;
+    int        i, j, k;
+    float      buff [0x4000];
+    Audiofile  A;
+    Convdata   *D;
 
     delete _convol;
     _convol = 0;
@@ -266,20 +267,25 @@ int ABprocess::set_convol (ABconfig *C)
     {
 	_enable |= ABconfig::EN_CONV;
         _cerror = true;
-	if (C->openconvfile ()) return 1;
-        k = C->_convdata.n_fram ();
+        if (A.open_read (C->_convfile)) return 1;
+        if ((A.chan () != 4) || (A.size () > 0x4000))
+        {
+            A.close ();
+            return 1;
+        }
+        k = A.size () / 4;
 	_convol = new Convol44 (_psize, k, _fsize, 0);
 	for (i = 0; i < 4; i++)
 	{
-	    C->_convdata.read_sect (i);
+	    A.read (buff, k);
 	    for (j = 0; j < 4; j++)
 	    {
 		D = new Convdata (_psize, k, 0);
-		D->init (C->_convdata.data (j), k, 4, 1.0f);
+		D->init (buff + j, k, 4, 1.0f);
 		_convol->set_conv (i, j, D);
 	    }
 	}
-	C->closeconvfile ();
+	A.close ();
 	_convol->reset ();
 	_cerror = false;
     }
