@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2025 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,14 +22,12 @@
 #define __ABPROCESS_H
 
 
-#include "kmeterdsp.h"
 #include "abconfig.h"
 #include "convol44.h"
 #include "hpfilt.h"
 #include "pmfilt.h"
 
 
-
 class ABprocess
 {
 public:
@@ -37,6 +35,8 @@ public:
     ABprocess (void);
     ~ABprocess (void);
 
+    enum { NORM_FUMA, NORM_SN3D, NORM_N3D };
+    
     void set_hpfil (float v) { _hpconf.setfreq (v / _fsamp); }
     void set_mute  (int m) { _mute = m; }
     void set_invb  (int m) { _invb = m; }
