@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2022 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -23,13 +23,15 @@
 #include <math.h>
 #include "styles.h"
 #include "global.h"
-#include "bformat.h"
 #include "mainwin.h"
+#include "abprocess.h"
 
 
-static const char *laba [4] = { "LF", "RF", "LB", "RB" };
-static const char *labb [4] = { "W", "X", "Y", "Z" };
-
+static const char  *laba [4]  = { "LF", "RF", "LB", "RB" };
+static const char  *labb_acn [4]  = { "0", "1", "2", "3" };
+static const char  *labb_fuma [4] = { "W", "X", "Y", "Z" };
+static const int   acnmap [4] = { 0, 3, 1, 2 };
+    
 
 Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jclient) :
     A_thread ("Main"),
@@ -58,14 +60,15 @@ Mainwin::Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jc
     x_resize (1000, 170);
 
     _confwin = new Confwin (parent, this, xres, 100, 100);
-    makegui ();
-    _bfnorm = Bformat::FM_FUMA;
-    p = xres->get (".bformat", "fuma");
+    _bform = ABprocess::NORM_SN3D;
+    p = xres->get (".bformat", "sn3d");
     if (p)
     {
-	if (!strcmp (p, "sn3d")) _bfnorm = Bformat::FM_SN3D;
-	if (!strcmp (p, "n3d"))  _bfnorm = Bformat::FM_N3D;
+	if (!strcmp (p, "fuma")) _bform = ABprocess::NORM_FUMA;
+	if (!strcmp (p, "sn3d")) _bform = ABprocess::NORM_SN3D;
+	if (!strcmp (p, "n3d"))  _bform = ABprocess::NORM_N3D;
     }
+    makegui ();
     setformat ();
 
     x_map (); 
@@ -97,17 +100,17 @@ Mainwin::~Mainwin (void)
  
 int Mainwin::process (void)
 {
-    int e;
+    int ev;
 
     if (_stop) handle_stop ();
-    e = get_event_timed ();
-    switch (e)
+    ev = get_event_timed ();
+    switch (ev)
     {
     case EV_TIME:
         handle_time ();
 	break;
     }
-    return e;
+    return ev;
 }
 
 
@@ -141,13 +144,16 @@ void Mainwin::clmesg (XClientMessageEvent *E)
 
 void Mainwin::handle_time (void)
 {
-    int   i;
+    int   j, k;
     float rms, dpk;
+    bool  acn;
 
-    for (i = 0; i < 4; i++)
+    acn = _b_monit->stat () && _bform != ABprocess::NORM_FUMA;
+    for (j = 0; j < 4; j++)
     {
-	_jclient->get_level (i, &rms, &dpk);
-	_meters [i]->update (rms, dpk);
+        k = acn ? acnmap [j] : j;
+	_jclient->get_level (j, &rms, &dpk);
+	_meters [k]->update (rms, dpk);
     }
     XFlush (dpy ());
     inc_time (50000);
@@ -314,19 +320,19 @@ void Mainwin::applconf (void)
 
 void Mainwin::setformat (void)
 {
-    _jclient->set_form (_bfnorm);
-    switch (_bfnorm)
+    _jclient->set_norm (_bform);
+    switch (_bform)
     {
-    case Bformat::FM_FUMA:
-        _t_form->set_text ("FuMa");
+    case ABprocess::NORM_SN3D:
+        _t_form->set_text ("SN3D ACN");
 	_t_form->set_color (XftColors [C_DISP_BG]->pixel, XftColors [C_DISP_FG1]);
 	break;
-    case Bformat::FM_SN3D:
-        _t_form->set_text ("SN3D");
+    case ABprocess::NORM_N3D:
+        _t_form->set_text ("N3D ACN");
 	_t_form->set_color (XftColors [C_DISP_BG]->pixel, XftColors [C_DISP_FG2]);
 	break;
-    case Bformat::FM_N3D:
-        _t_form->set_text ("N3D");
+    case ABprocess::NORM_FUMA:
+        _t_form->set_text ("FuMa");
 	_t_form->set_color (XftColors [C_DISP_BG]->pixel, XftColors [C_DISP_FG2]);
 	break;
     default:	
@@ -346,7 +352,8 @@ void Mainwin::syncaudio (int e)
 void Mainwin::makegui (void)
 {
     int i, x, y;
-
+    const char **labb;
+    
     x = 10; 
     y = 10;
     Bst0.size.x = 40;
@@ -389,6 +396,7 @@ void Mainwin::makegui (void)
 
     _w_level = new X_subwin (this, 285, 5, 502, 124, XftColors [C_DISP_BG]->pixel);
     y = 24;
+    labb = _bform == ABprocess::NORM_FUMA ? labb_fuma : labb_acn;
     for (i = 0; i < 4; i++)
     {
         _meters [i] = new Kmeter (_w_level, 26, y + 4, Kmeter::HOR, Kmeter::K20);
@@ -488,6 +496,5 @@ void Mainwin::redraw (void)
 	y += Kmeter::LINEW + 8;
     }
     XPutImage (dpy (), _w_level->win (), dgc (), I, 0, 0, 26, y + 12, I->width, 16);
-
 }
 
