@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2022 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -23,25 +23,31 @@
 #include <getopt.h>
 #include <stdio.h>
 #include <math.h>
+#include "global.h"
 #include "audiofile.h"
 #include "abprocess.h"
 
 
 enum
 {
-     HELP, STIN,
-     HPF, INVX, INVY, INVZ, ENDF, FUMA, SN3D, N3D,
-     CAF, WAV, AMB, AIFF, FLAC, BIT16, BIT24, FLOAT, REC, TRI, LIPS 
+     HELP, STIN, HPF,
+     ENDF, INVX, INVY, INVZ,
+     SN3D, N3D, FUMA,
+     ACN, WXYZ,
+     CAF, WAV, AMB, AIFF, FLAC,
+     BIT16, BIT24, FLOAT,
+     REC, TRI, SHA 
 };
 enum { BUFFSIZE = 256 };
 
 
 static float hpfr = 0;
-static int   norm = Bformat::FM_FUMA;
+static bool  stin = false;
+static bool  wxyz = false;
+static bool  endf = false;
 static int   invb = 0;
-static int   endf = 0;
-static int   stin = 0;
-static int   type = Audiofile::TYPE_AMB;
+static int   norm = ABprocess::NORM_SN3D;
+static int   type = Audiofile::TYPE_WAV;
 static int   form = Audiofile::FORM_24BIT;
 static int   dith = Audiofile::DITHER_NONE;
 
@@ -49,19 +55,20 @@ static int   dith = Audiofile::DITHER_NONE;
 static void help (void)
 {
     fprintf (stderr, "\ntetrafile %s\n", VERSION);
-    fprintf (stderr, "(C) 2007-2014 Fons Adriaensen  <fons@linuxaudio.org>\n");
-    fprintf (stderr, "Usage: tetrafile <options> <config file> <input file(s)> <output file>.\n");
+    fprintf (stderr, "(C) 2006-2022 Fons Adriaensen  <fons@linuxaudio.org>\n");
+    fprintf (stderr, "Usage: tetrafile <options> <config file> <input file(s)> <output file>.\n\n");
     fprintf (stderr, "Options:\n");
     fprintf (stderr, "  Display this text:     --help\n");
     fprintf (stderr, "  Stereo input files:    --stin\n");
     fprintf (stderr, "  Highpass filter:       --hpf <frequency>\n");
-    fprintf (stderr, "  B format standard:     --fuma, --sn3d, --n3d\n");
-    fprintf (stderr, "  B format inversion:    --invx, --invy, --invz\n");
     fprintf (stderr, "  Endfire mode:          --endf\n");
-    fprintf (stderr, "  Output file type:      --amb, --caf, --wav, -aiff, --flac\n");
+    fprintf (stderr, "  B form inversion:      --invx, --invy, --invz\n");
+    fprintf (stderr, "  B form gains:          --sn3d, --n3d, --fuma\n");
+    fprintf (stderr, "  B form channel order:  --acn, --wxyz\n");
+    fprintf (stderr, "  Output file type:      --caf, --wav, -aiff, --flac, --amb\n");
     fprintf (stderr, "  Output sample format:  --16bit, --24bit, --float\n");
-    fprintf (stderr, "  Dither type (16 bit):  --rec, --tri, --lips\n");
-    fprintf (stderr, "The default options are --fuma, --amb, --24bit.\n");
+    fprintf (stderr, "  Dither type (16 bit):  --rec, --tri, --sha\n");
+    fprintf (stderr, "\nThe default options are --sn3d, --acn --wav, --24bit.\n\n");
     exit (1);
 }
 
@@ -70,25 +77,27 @@ static struct option options [] =
 {
     { "help",  0, 0, HELP  },
     { "stin",  0, 0, STIN  },
+    { "endf",  0, 0, ENDF  },
     { "invx",  0, 0, INVX  },
     { "invy",  0, 0, INVY  },
     { "invz",  0, 0, INVZ  },
-    { "endf",  0, 0, ENDF  },
-    { "fuma",  0, 0, FUMA  },
     { "sn3d",  0, 0, SN3D  },
     { "n3d",   0, 0, N3D   },
-    { "amb",   0, 0, AMB   },
+    { "fuma",  0, 0, FUMA  },
+    { "acn",   0, 0, ACN   },
+    { "wxyz",  0, 0, WXYZ  },
     { "caf",   0, 0, CAF   },
     { "wav",   0, 0, WAV   },
     { "aiff",  0, 0, AIFF  },
     { "flac",  0, 0, FLAC  },
+    { "amb",   0, 0, AMB   },
     { "hpf",   1, 0, HPF   },
     { "16bit", 0, 0, BIT16 },
     { "24bit", 0, 0, BIT24 },
     { "float", 0, 0, FLOAT },
     { "rec",   0, 0, REC   },
     { "tri",   0, 0, TRI   },
-    { "lips",  0, 0, LIPS  },
+    { "sha",   0, 0, SHA   },
     { 0, 0, 0, 0 }
 };
 
@@ -106,7 +115,7 @@ static void procoptions (int ac, char *av [])
 	    help ();
 	    break;
 	case STIN:
-	    stin = 1;
+	    stin = true;
 	    break;
 	case HPF:
 	    if ((sscanf (optarg, "%f", &hpfr) != 1) || (hpfr < 10) || (hpfr > 160))
@@ -115,6 +124,9 @@ static void procoptions (int ac, char *av [])
 		exit (1);
 	    }
 	    break;
+	case ENDF:
+	    endf = true;
+	    break;
 	case INVX:
 	    invb |= 2;
 	    break;
@@ -124,17 +136,20 @@ static void procoptions (int ac, char *av [])
 	case INVZ:
 	    invb |= 8;
 	    break;
-	case ENDF:
-	    endf = 1;
-	    break;
-	case FUMA:
-	    norm = Bformat::FM_FUMA;
-	    break;
 	case SN3D:
-	    norm = Bformat::FM_SN3D;
+	    norm = ABprocess::NORM_SN3D;
 	    break;
 	case N3D:
-	    norm = Bformat::FM_N3D;
+	    norm = ABprocess::NORM_N3D;
+	    break;
+	case FUMA:
+	    norm = ABprocess::NORM_FUMA;
+	    break;
+	case ACN:
+	    wxyz = false;
+	    break;
+	case WXYZ:
+	    wxyz = true;
 	    break;
 	case CAF:
 	    type = Audiofile::TYPE_CAF;
@@ -142,15 +157,15 @@ static void procoptions (int ac, char *av [])
 	case WAV:
 	    type = Audiofile::TYPE_WAV;
 	    break;
-	case AMB:
-	    type = Audiofile::TYPE_AMB;
-	    break;
 	case AIFF:
 	    type = Audiofile::TYPE_AIFF;
 	    break;
 	case FLAC:
 	    type = Audiofile::TYPE_FLAC;
 	    break;
+	case AMB:
+	    type = Audiofile::TYPE_AMB;
+	    break;
 	case BIT16:
 	    form = Audiofile::FORM_16BIT;
 	    break;
@@ -166,7 +181,7 @@ static void procoptions (int ac, char *av [])
 	case TRI:
 	    dith = Audiofile::DITHER_TRIA;
 	    break;
-	case LIPS:
+	case SHA:
 	    dith = Audiofile::DITHER_LIPS;
 	    break;
  	}
@@ -181,17 +196,22 @@ int main (int ac, char *av [])
     Audiofile     Aout;
     ABprocess     abproc;
     ABconfig      config;
-    unsigned int  i, k, n, rate;
+    unsigned int  i, k, rate;
     float         *buff, *inp [4], *out [4];
     float         *p;
+    int           nargs, nchan;
 
+    
     procoptions (ac, av);
-    if (ac - optind < 3 + stin)
+    nargs = stin ? 4 : 3;
+    nchan = stin ? 2 : 4;
+
+    if (ac - optind < nargs)
     {
         fprintf (stderr, "Missing arguments, try --help.\n");
 	return 1;
     }
-    if (ac - optind > 3 + stin )
+    if (ac - optind > nargs )
     {
         fprintf (stderr, "Too many arguments, try --help.\n");
 	return 1;
@@ -203,16 +223,15 @@ int main (int ac, char *av [])
 	return 1;
     }
 
-    n = stin ? 2 : 4;
     optind++;
     if (Ainp1.open_read (av [optind]))
     {
 	fprintf (stderr, "Can't open input file '%s'.\n", av [optind]);
 	return 1;
     }
-    if (Ainp1.chan () != (int) n)
+    if (Ainp1.chan () != (int) nchan)
     {
-	fprintf (stderr, "Input file '%s' does not have %d channels.\n", av [optind], n);
+	fprintf (stderr, "Input file '%s' should have %d channels.\n", av [optind], nchan);
 	Ainp1.close ();
 	return 1;
     }
@@ -227,9 +246,9 @@ int main (int ac, char *av [])
 	    Ainp1.close ();
 	    return 1;
         }
-        if (Ainp2.chan () != (int) n)
+        if (Ainp2.chan () != 2)
         {
-	    fprintf (stderr, "Input file '%s' does not have %d channels.\n", av [optind], n);
+	    fprintf (stderr, "Input file '%s' should have 2 channels.\n", av [optind]);
 	    Ainp1.close ();
 	    Ainp2.close ();
 	    return 1;
@@ -280,7 +299,7 @@ int main (int ac, char *av [])
 	out [i] = new float [BUFFSIZE];
     }
 
-    while (1)
+    while (true)
     {
         k = Ainp1.read (buff, BUFFSIZE);
         if (k)
@@ -311,12 +330,25 @@ int main (int ac, char *av [])
 	    }
 
 	    abproc.process (k, inp, out); 
-            for (i = 0, p = buff; i < k; i++, p += 4)
-	    {
-		p [0] = out [0][i];
-		p [1] = out [1][i];
-		p [2] = out [2][i];
-		p [3] = out [3][i];
+	    if (wxyz)
+            {		
+		for (i = 0, p = buff; i < k; i++, p += 4)
+		{
+		    p [0] = out [0][i];
+		    p [1] = out [1][i];
+		    p [2] = out [2][i];
+		    p [3] = out [3][i];
+		}
+	    }
+	    else
+            {		
+		for (i = 0, p = buff; i < k; i++, p += 4)
+		{
+		    p [0] = out [0][i];
+		    p [1] = out [2][i];
+		    p [2] = out [3][i];
+		    p [3] = out [1][i];
+		}
 	    }
             Aout.write (buff, k);
 	}
