@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------
 //
-//  Copyright (C) 2006-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2006-2022 Fons Adriaensen <fons@linuxaudio.org>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #include <string.h>
 #include <math.h>
 #include "virtmic.h"
-#include "bformat.h"
+#include "abprocess.h"
 
 
 #define PIF 3.141592f
@@ -97,12 +97,12 @@ void Virtmic::process (int n, float *W, float *X,float *Y, float *Z, float *L, f
 	    y = _csy;
 	    z = _csz;
 	    d = _direc;
-	    if (_norm == Bformat::FM_N3D) d *= 0.57735f;
+	    if (_norm == ABprocess::NORM_N3D) d *= 0.57735f;
 	    _csw = 1 - _direc;
 	    _csx = d * ca * ce * cv;
             _csy = d * sa * ce * cv;
             _csz = d * cv * se;
-	    if (_norm == Bformat::FM_FUMA) _csw *= 1.41421f;
+	    if (_norm == ABprocess::NORM_FUMA) _csw *= 1.41421f;
 	    dw = diff (k, w, _csw);
 	    dx = diff (k, x, _csx);
             dy = diff (k, y, _csy);
@@ -126,7 +126,8 @@ void Virtmic::process (int n, float *W, float *X,float *Y, float *Z, float *L, f
    	    {
                 x += dx;
                 y += dy;
-		D [i] = x * X [i] + y * Y [i];
+		if (_mono) D [i] = 0;
+		else D [i] = x * X [i] + y * Y [i];
             }
 	}
         else
@@ -134,11 +135,11 @@ void Virtmic::process (int n, float *W, float *X,float *Y, float *Z, float *L, f
    	    for (i = 0; i < k; i++)
 	    {
                 S [i] = _csw * W [i] + _csx * X [i] + _csy * Y [i] + _csz * Z [i]; 
-                D [i] = _cdx * X [i] + _cdy * Y [i];
+		if (_mono) D [i] = 0;
+                else D [i] = _cdx * X [i] + _cdy * Y [i];
 	    }
 	}
 
-	if (_mono) memset (D, 0, k * sizeof (float));
 	if (_xtalk)
 	{
 	    zs = _zs;
